@@ -3,8 +3,8 @@ import json
 from office365.delta_collection import DeltaCollection
 from office365.directory.applications.app_role_assignment import AppRoleAssignmentCollection
 from office365.directory.licenses.assigned_license import AssignedLicense
-from office365.directory.directory_object import DirectoryObject
-from office365.directory.directory_object_collection import DirectoryObjectCollection
+from office365.directory.object import DirectoryObject
+from office365.directory.object_collection import DirectoryObjectCollection
 from office365.directory.resource_specific_permission_grant import ResourceSpecificPermissionGrant
 from office365.entity_collection import EntityCollection
 from office365.onedrive.drives.drive import Drive
