@@ -53,31 +53,28 @@ class GraphClient(ClientRuntimeContext):
         :param () -> dict acquire_token_callback: Acquire token function
         """
         super(GraphClient, self).__init__()
-        self._pending_request = ODataRequest(self, V4JsonFormat())
-        self._pending_request.beforeExecute += self._build_specific_query
+        self._pending_request = None
         self._resource = "https://graph.microsoft.com"
         self._authority_host_url = "https://login.microsoftonline.com"
         self._acquire_token_callback = acquire_token_callback
 
-    def build_request(self, query):
-        """
-        :type: office365.runtime.queries.client_query.ClientQuery
-        """
-        request = super(GraphClient, self).build_request(query)
-        self._build_specific_query(request)
-        return request
-
     def execute_batch(self, items_per_batch=100):
         """Constructs and submit a batch request
 
         :param int items_per_batch: Maximum to be selected for bulk operation
         """
-        batch_request = ODataV4BatchRequest(self, items_per_batch)
-        [batch_request.add_query(qry) for qry in self.pending_request()]
-        batch_request.execute_query()
+        batch_request = ODataV4BatchRequest(V4JsonFormat())
+        batch_request.beforeExecute += self._authenticate_request
+        while self.has_pending_request:
+            qry = self._get_next_query(items_per_batch)
+            batch_request.execute_query(qry)
         return self
 
     def pending_request(self):
+        if self._pending_request is None:
+            self._pending_request = ODataRequest(V4JsonFormat())
+            self._pending_request.beforeExecute += self._authenticate_request
+            self._pending_request.beforeExecute += self._build_specific_query
         return self._pending_request
 
     def service_root_url(self):
@@ -85,17 +82,16 @@ class GraphClient(ClientRuntimeContext):
 
     def _build_specific_query(self, request):
         """
-        Builds Graph specific request
+        Builds Graph specific HTTP request
 
         :type request: RequestOptions
         """
-        query = self.pending_request().current_query
-        if isinstance(query, UpdateEntityQuery):
+        if isinstance(self.current_query, UpdateEntityQuery):
             request.method = HttpMethod.Patch
-        elif isinstance(query, DeleteEntityQuery):
+        elif isinstance(self.current_query, DeleteEntityQuery):
             request.method = HttpMethod.Delete
 
-    def authenticate_request(self, request):
+    def _authenticate_request(self, request):
         """
         Authenticate request
 
