@@ -1,5 +1,6 @@
 import abc
 from time import sleep
+from typing import TypeVar
 
 from office365.runtime.client_request_exception import ClientRequestException
 from office365.runtime.client_result import ClientResult
@@ -8,16 +9,34 @@ from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.queries.client_query import ClientQuery
 from office365.runtime.queries.read_entity import ReadEntityQuery
 
+T = TypeVar('T', bound='ClientObject')
+
 
 class ClientRuntimeContext(object):
 
+    def __init__(self):
+        self._queries = []
+        self._current_query = None
+
+    @property
+    def current_query(self):
+        """
+        :rtype: office365.runtime.queries.client_query.ClientQuery
+        """
+        return self._current_query
+
+    @property
+    def has_pending_request(self):
+        return len(self._queries) > 0
+
     def build_request(self, query):
         """
         Builds a request
 
         :type query: office365.runtime.queries.client_query.ClientQuery
         """
-        return self.pending_request().build_request(query)
+        self._current_query = query
+        return self.pending_request().build_custom_request(query)
 
     def execute_query_retry(self, max_retry=5, timeout_secs=5, success_callback=None, failure_callback=None,
                             exceptions=(ClientRequestException,)):
@@ -35,10 +54,10 @@ class ClientRuntimeContext(object):
             try:
                 self.execute_query()
                 if callable(success_callback):
-                    success_callback(self.pending_request().current_query.return_type)
+                    success_callback(self.current_query.return_type)
                 break
             except exceptions as e:
-                self.add_query(self.pending_request().current_query)
+                self.add_query(self.current_query)
                 if callable(failure_callback):
                     failure_callback(retry, e)
                 sleep(timeout_secs)
@@ -57,20 +76,13 @@ class ClientRuntimeContext(object):
         """
         pass
 
-    @abc.abstractmethod
-    def authenticate_request(self, request):
-        """
-        :type request: office365.runtime.http.request_options.RequestOptions
-        """
-        pass
-
     def load(self, client_object, properties_to_retrieve=None, before_loaded=None, after_loaded=None):
         """Prepare retrieval query
 
         :type properties_to_retrieve: list[str] or None
         :type client_object: office365.runtime.client_object.ClientObject
         :type before_loaded: (office365.runtime.http.request_options.RequestOptions) -> None
-        :type after_loaded: (office365.runtime.client_object.ClientObject) -> None
+        :type after_loaded: (T) -> None
         """
         qry = ReadEntityQuery(client_object, properties_to_retrieve)
         self.add_query(qry)
@@ -79,6 +91,7 @@ class ClientRuntimeContext(object):
         if callable(after_loaded):
             def _action():
                 after_loaded(client_object)
+
             self.after_query_execute(qry, _action)
         return self
 
@@ -111,7 +124,7 @@ class ClientRuntimeContext(object):
             :type resp: requests.Response
             """
             resp.raise_for_status()
-            if self.pending_request().current_query.id == query.id:
+            if self.current_query.id == query.id:
                 self.pending_request().afterExecute -= _process_response
                 action(*args, **kwargs)
 
@@ -144,17 +157,20 @@ class ClientRuntimeContext(object):
 
     def execute_query(self):
         """Submit request(s) to the server"""
-        self.pending_request().execute_query()
+        while self.has_pending_request:
+            qry = self._get_next_query()
+            self.pending_request().execute_query(qry)
 
     def add_query(self, query):
         """
         :type query: office365.runtime.queries.client_query.ClientQuery
         """
-        self.pending_request().add_query(query)
+        self._queries.append(query)
         return self
 
     def clear(self):
-        self.pending_request().clear()
+        self._current_query = None
+        self._queries = []
         return self
 
     def get_metadata(self):
@@ -180,3 +196,17 @@ class ClientRuntimeContext(object):
         self.add_query(qry)
         return return_type
 
+    def _get_next_query(self, count=1):
+        """
+        :type count: int
+        """
+        if count == 1:
+            qry = self._queries.pop(0)
+        else:
+            from office365.runtime.queries.batch import BatchQuery
+            qry = BatchQuery(self)
+            while self.has_pending_request and count > 0:
+                qry.add(self._queries.pop(0))
+                count = count - 1
+        self._current_query = qry
+        return qry
