@@ -2,7 +2,6 @@ import copy
 
 from office365.runtime.auth.authentication_context import AuthenticationContext
 from office365.runtime.auth.user_credential import UserCredential
-from office365.runtime.client_result import ClientResult
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
@@ -10,7 +9,6 @@ from office365.runtime.odata.v3.json_light_format import JsonLightFormat
 from office365.runtime.odata.v3.batch_request import ODataBatchV3Request
 from office365.runtime.odata.request import ODataRequest
 from office365.runtime.queries.delete_entity import DeleteEntityQuery
-from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.portal.sites.status import SiteStatus
@@ -131,24 +129,14 @@ class ClientContext(ClientRuntimeContext):
 
         :param int items_per_batch: Maximum to be selected for bulk operation
         """
-        batch_request = ODataBatchV3Request(self, items_per_batch)
-
-        def _prepare_batch_request(request):
-            self.ensure_form_digest(request)
-
-        batch_request.beforeExecute += _prepare_batch_request
-        [batch_request.add_query(qry) for qry in self.pending_request()]
-        batch_request.execute_query()
+        batch_request = ODataBatchV3Request(JsonLightFormat())
+        batch_request.beforeExecute += self._authenticate_request
+        batch_request.beforeExecute += self._ensure_form_digest
+        while self.has_pending_request:
+            qry = self._get_next_query(items_per_batch)
+            batch_request.execute_query(qry)
         return self
 
-    def build_request(self, query):
-        """
-        :type query: office365.runtime.queries.client_query.ClientQuery
-        """
-        request = super(ClientContext, self).build_request(query)
-        self._build_modification_query(request)
-        return request
-
     def pending_request(self):
         """
         Provides access to underlying request instance
@@ -156,48 +144,32 @@ class ClientContext(ClientRuntimeContext):
         :return: ODataRequest
         """
         if self._pending_request is None:
-            self._pending_request = ODataRequest(self, JsonLightFormat())
+            self._pending_request = ODataRequest(JsonLightFormat())
+            self._pending_request.beforeExecute += self._authenticate_request
             self._pending_request.beforeExecute += self._build_modification_query
         return self._pending_request
 
-    def ensure_form_digest(self, request_options):
+    def _ensure_form_digest(self, request):
         """
-        :type request_options: RequestOptions
+        :type request: RequestOptions
         """
         if not self.context_info.is_valid:
-            self._ctx_web_info = self.get_context_web_information(request_options=request_options)
-        request_options.set_header('X-RequestDigest', self._ctx_web_info.FormDigestValue)
+            self._ctx_web_info = self._get_context_web_information()
+        request.set_header('X-RequestDigest', self._ctx_web_info.FormDigestValue)
 
-    def get_context_web_information(self, request_options=None):
+    def _get_context_web_information(self):
         """Returns an ContextWebInformation object that specifies metadata about the site"""
+        client = ODataRequest(JsonLightFormat())
+        client.beforeExecute += self._authenticate_request
         request = RequestOptions("{0}/contextInfo".format(self.service_root_url()))
         request.method = HttpMethod.Post
-        if request_options:
-            request.proxies = request_options.proxies
-            request.verify = request_options.verify
-        response = self.pending_request().execute_request_direct(request)
-        json = response.json()
+        response = client.execute_request_direct(request)
         json_format = JsonLightFormat()
         json_format.function = "GetContextWebInformation"
         return_value = ContextWebInformation()
-        self.pending_request().map_json(json, return_value, json_format)
+        client.map_json(response.json(), return_value, json_format)
         return return_value
 
-    def get_context_web_information_ex(self):
-        """Returns an ContextWebInformation object that specifies metadata about the site"""
-        return_type = ClientResult(self, ContextWebInformation())
-
-        def _construct_request(request):
-            """
-            :type request: office365.runtime.http.request_options.RequestOptions
-            """
-            request.url = self.service_root_url() + "/contextInfo"
-
-        qry = ServiceOperationQuery(self.web, "GetContextWebInformation", None, None, None, return_type)
-        self.before_execute(_construct_request)
-        self.add_query(qry)
-        return return_type
-
     def execute_query_with_incremental_retry(self, max_retry=5):
         """Handles throttling requests."""
         settings = {
@@ -236,7 +208,7 @@ class ClientContext(ClientRuntimeContext):
             ctx.clear()
         return ctx
 
-    def authenticate_request(self, request):
+    def _authenticate_request(self, request):
         self.authentication_context.authenticate_request(request)
 
     def _build_modification_query(self, request):
@@ -245,16 +217,14 @@ class ClientContext(ClientRuntimeContext):
 
         :type request: RequestOptions
         """
-        query = self.pending_request().current_query
-
         if request.method == HttpMethod.Post:
-            self.ensure_form_digest(request)
+            self._ensure_form_digest(request)
         # set custom SharePoint control headers
         if isinstance(self.pending_request().default_json_format, JsonLightFormat):
-            if isinstance(query, DeleteEntityQuery):
+            if isinstance(self.current_query, DeleteEntityQuery):
                 request.ensure_header("X-HTTP-Method", "DELETE")
                 request.ensure_header("IF-MATCH", '*')
-            elif isinstance(query, UpdateEntityQuery):
+            elif isinstance(self.current_query, UpdateEntityQuery):
                 request.ensure_header("X-HTTP-Method", "MERGE")
                 request.ensure_header("IF-MATCH", '*')
 
@@ -347,9 +317,8 @@ class ClientContext(ClientRuntimeContext):
     @property
     def models(self):
         """Alias to collection of SPMachineLearningModel"""
-        from office365.sharepoint.contentcenter.machinelearning.model import SPMachineLearningModel
-        from office365.sharepoint.base_entity_collection import BaseEntityCollection
-        return BaseEntityCollection(self, SPMachineLearningModel, ResourcePath("models"))
+        from office365.sharepoint.contentcenter.machinelearning.model_collection import SPMachineLearningModelCollection
+        return SPMachineLearningModelCollection(self, ResourcePath("models"))
 
     @property
     def group_site_manager(self):
@@ -363,6 +332,12 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.portal.groups.service import GroupService
         return GroupService(self, ResourcePath("GroupService"))
 
+    @property
+    def page_diagnostics(self):
+        """Alias to PageDiagnosticsController"""
+        from office365.sharepoint.publishing.diagnostics.controller import PageDiagnosticsController
+        return PageDiagnosticsController(self)
+
     @property
     def people_manager(self):
         """Alias to PeopleManager"""
@@ -386,6 +361,18 @@ class ClientContext(ClientRuntimeContext):
         """Alias to HubSiteCollection. Gets information about all hub sites that the current user can access."""
         return HubSiteCollection(self, ResourcePath("hubSites"))
 
+    @property
+    def hub_sites_utility(self):
+        """Alias to HubSitesUtility."""
+        from office365.sharepoint.portal.hub_sites_utility import SPHubSitesUtility
+        return SPHubSitesUtility(self, ResourcePath("HubSitesUtility"))
+
+    @property
+    def machine_learning(self):
+        """Alias to SPMachineLearningHub"""
+        from office365.sharepoint.contentcenter.machinelearning.hub import SPMachineLearningHub
+        return SPMachineLearningHub(self, ResourcePath("machinelearning"))
+
     @property
     def site_pages(self):
         """Alias to SitePageService. Represents a set of APIs to use for managing site pages."""
@@ -400,7 +387,7 @@ class ClientContext(ClientRuntimeContext):
     @property
     def site_linking_manager(self):
         """Alias to Microsoft.SharePoint.Portal.SiteLinkingManager. """
-        from office365.sharepoint.portal.sites.linking_manager import SiteLinkingManager
+        from office365.sharepoint.portal.linkedsites.manager import SiteLinkingManager
         return SiteLinkingManager(self, ResourcePath("siteLinkingManager"))
 
     @property
@@ -439,7 +426,7 @@ class ClientContext(ClientRuntimeContext):
         if self.is_tenant:
             return Tenant(self)
         else:
-            admin_ctx = self.clone(self.tenant_url)
+            admin_ctx = self.clone(self.tenant_url, False)
             return Tenant(admin_ctx)
 
     @property
