@@ -5,6 +5,7 @@ from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.activities.entity import SPActivityEntity
+from office365.sharepoint.activities.logger import ActivityLogger
 from office365.sharepoint.alerts.collection import AlertCollection
 from office365.sharepoint.authentication.acs_service_principal_info import SPACSServicePrincipalInfo
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
@@ -79,6 +80,16 @@ class Web(SecurableObject):
         super(Web, self).__init__(context, resource_path)
         self._web_url = None
 
+    def add_cross_farm_message(self, message):
+        """
+        :param str message:
+        """
+        payload = {"messagePayloadBase64": message}
+        return_type = ClientResult(self.context, bool())
+        qry = ServiceOperationQuery(self, "AddCrossFarmMessage", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_site_script(self, include_branding=True, included_lists=None, include_links_to_exported_items=True,
                         include_regional_settings=True):
         """
@@ -200,11 +211,10 @@ class Web(SecurableObject):
 
         :type context: office365.sharepoint.client_context.ClientContext
         """
-        result = ClientResult(context, ContextWebInformation())
-        qry = ServiceOperationQuery(context.web, "GetContextWebInformation", None, None, None, result)
-        qry.static = True
+        return_type = ClientResult(context, ContextWebInformation())
+        qry = ServiceOperationQuery(context.web, "GetContextWebInformation", None, None, None, return_type, True)
         context.add_query(qry)
-        return result
+        return return_type
 
     @staticmethod
     def get_web_url_from_page_url(context, page_full_url):
@@ -600,6 +610,16 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return return_type
 
+    def ensure_tenant_app_catalog(self, caller_id):
+        """
+        :param str caller_id:
+        """
+        return_type = ClientResult(self.context, bool())
+        payload = {"callerId": caller_id}
+        qry = ServiceOperationQuery(self, "EnsureTenantAppCatalog", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def get_user_effective_permissions(self, user_name):
         """Gets the effective permissions that the specified user has within the current application scope.
 
@@ -1265,6 +1285,11 @@ class Web(SecurableObject):
                                    BaseEntityCollection(self.context, SPActivityEntity,
                                                         ResourcePath("Activities", self.resource_path)))
 
+    @property
+    def activity_logger(self):
+        return self.properties.get("ActivityLogger",
+                                   ActivityLogger(self.context, ResourcePath("ActivityLogger", self.resource_path)))
+
     @property
     def allow_rss_feeds(self):
         """Gets a Boolean value that specifies whether the site collection allows RSS feeds.
@@ -1673,6 +1698,7 @@ class Web(SecurableObject):
         if default_value is None:
             property_mapping = {
                 "AccessRequestsList": self.access_requests_list,
+                "ActivityLogger": self.activity_logger,
                 "AvailableFields": self.available_fields,
                 "AvailableContentTypes": self.available_content_types,
                 "AssociatedOwnerGroup": self.associated_owner_group,
@@ -1715,7 +1741,7 @@ class Web(SecurableObject):
     @property
     def resource_url(self):
         """Returns Web url"""
-        val = super(Web, self).resource_url
+        orig_resource_url = super(Web, self).resource_url
         if self._web_url is not None:
-            val = val.replace(self.context.service_root_url(), self._web_url + '/_api')
-        return val
+            orig_resource_url = orig_resource_url.replace(self.context.service_root_url(), self._web_url + '/_api')
+        return orig_resource_url
